#!/usr/bin/env python3
from email.parser import BytesParser
import email.policy


mail_parser = BytesParser(policy=email.policy.default)


def check_message(filename):
    """
    Return True if the specified message contains mislabeled Windows-1252 text.
    """
    with open(filename, 'rb') as f:
        message = mail_parser.parse(f)

    for part in message.walk():
        if part.get_content_type() != 'text/plain' or \
           part.get_content_charset() != 'iso-8859-1':
            continue

        body = part.get_content()
        for char in body:
            code = ord(char)
            if code > 0x80 and code < 0xa0:
                return True

    return False


def main(args):
    for arg in args:
        if check_message(arg):
            print(arg)


if __name__ == '__main__':
    import sys
    main(sys.argv)
